@@ -58,7 +58,7 @@
 
 #include <QtGui/QMessageBox>
 
-Widget::Widget(QWidget *parent) : QProgressBar (parent), _screenOff(false), _pollingInterval(10) // 10 min default polling
+Widget::Widget(QWidget *parent) : QProgressBar (parent), _screenOff(false), _pollingInterval(10) // 10 sec default polling
 {
     QCoreApplication::instance()->setApplicationName("Hildon-Desktop battery level widget");
 
@@ -90,11 +90,11 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _screenOff(false), _pol
 			                			MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(QString)));
 
 	pollSlider = new QSlider(Qt::Horizontal);
-	pollSlider->setRange(0, 60);
-	pollSlider->setSingleStep(1);
+	pollSlider->setRange(0, 500);
+	pollSlider->setSingleStep(10);
 	pollSlider->setValue(10);
 	pollValueLabel = new QLabel;
-	pollValueLabel->setText("Polling Interval : " + QString::number(_pollingInterval) + "min");
+	pollValueLabel->setText("Polling Interval : " + QString::number(_pollingInterval) + "sec");
 
 	// sytle and color widget objects
 	styleWindow = new QMainWindow;
@@ -181,7 +181,7 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _screenOff(false), _pol
 
 	// polling timer and its connect slot
 	_timer = new QTimer;
-	_timer->start(_pollingInterval*60000);
+	_timer->start(_pollingInterval*1000);
 	updateBatteryLevel();
 
 	connect(_timer, SIGNAL(timeout()), this, SLOT(updateBatteryLevel()));
@@ -337,13 +337,14 @@ void Widget::displayStateChanged(QString displayState)
 	if (displayState == QLatin1String(MCE_DISPLAY_OFF_STRING))
 	{
 		_screenOff = true;
-		qDebug() << "Stopping timer now screen is off";
+		//qDebug() << "Stopping timer now screen is off";
 	}
 	else if (displayState != QLatin1String(MCE_DISPLAY_OFF_STRING))
 	{
 		_screenOff = false;
-		qDebug() << "Starting timer now screen is on";
-		_timer->start(_pollingInterval*60000);
+		//qDebug() << "Starting timer now screen is on";
+		updateBatteryLevel(); // update the level as soon as screen is on before starting the timer
+		_timer->start(_pollingInterval*1000);
 	}
 }
 
@@ -351,8 +352,8 @@ void Widget::changePollInterval(int value)
 { 
 	_timer->stop();
 	_pollingInterval = value;
-	pollValueLabel->setText("Polling Interval : " + QString::number(_pollingInterval) + "min");
-	_timer->start(_pollingInterval*60000);
+	pollValueLabel->setText("Polling Interval : " + QString::number(_pollingInterval) + "sec");
+	_timer->start(_pollingInterval*1000);
 }
 
 void Widget::showAbout()
